@@ -35,7 +35,7 @@ def download_songs(songs, download_directory, format_string, skip_mp3):
 
         with youtube_dl.YoutubeDL(ydl_opts) as ydl:
             try:
-                log.debug(ydl.download([query]))
+                ydl.download([query])
             except Exception as e:
                 log.debug(e)
                 print('Failed to download: {}, please ensure YouTubeDL is up-to-date. '.format(query))
